Instance Handling
=================

:program:`CrunchyFrog` is a single-process application.
If you start this program it first tries to connect to an already
running instance. If a running instance is found it creates a new
instance with the given command line arguments.

.. todo:: Functions for instance handling
